# Types: IMAGE, VIDEO, SOUND
EXT = {
    "JPG": "IMAGE",
    "MKV": "VIDEO",
    "MP3": "SOUND",
    "SH": "SHELL",
    "PEM": "KEYS",
    "JAR": "JAVA",
    "PNG": "IMAGE",
    "TAR": "PACKAGE",
    "HTML": "WEB",
    "ZIP": "PACKAGE",
    "XZ": "PACKAGE",
    "GZ": "PACKAGE",
    "RAR": "PACKAGE"
}